@@ -5,7 +5,7 @@ Main usage:
 
     >>> from pipeline_telemetry.main import Telemetry
     >>> telemetry = Telemetry(
-            process_name, process_type, telemetry_rules, storage_class)
+            source_name, process_type, telemetry_rules, storage_class)
     >>> pipeline_telemetry.add(sub_process_type, data, errors)
     >>> pipeline_telemetry.save_and_close()
 
@@ -15,7 +15,7 @@ that the sub process returned. In the final step the telementry is saved and
 closed
 
 Arguments
-    - process_name (str):
+    - source_name (str):
         Process name for the pipeline process that this telemetry is reporting
         on. Name is free to choose but make sure it is a unique name for each
         unique process as it will otherwise be difficult to use the telemetry
@@ -29,7 +29,19 @@ Arguments
         is added to the telemetry object. With these rules you can define custom
         conditional counts and errors that can be applied to the provided data.
         See telemetry rules section for more detail
-
     -
 """
-from .validators import has_key, validate_entries  # noqa: F401
+# flake8: noqa F401
+from errors import ListErrors
+
+from .decorator import add_mongo_telemetry, add_telemetry
+from .helper import increase_base_count, increase_fail_count, \
+    is_telemetry_counter
+from .main import Telemetry
+from .settings.data_class import ProcessType, TelemetryCounter
+from .settings.process_type import ProcessTypes
+from .settings.settings import BaseEnumerator, DefaultProcessTypes
+from .settings.telemetry_errors import ValidationErrors
+
+ProcessTypes.register_process_types(DefaultProcessTypes)
+ListErrors.register_errors(ValidationErrors)
